@@ -99,6 +99,7 @@ ENTITYREFERENCE = "entityReference"
 EXTERNALCODESET = "externalCodeSet"
 EXTERNALLYDEFINEDFORMAT = "externallyDefinedFormat"
 EML = "eml"
+EMPHASIS = "emphasis"
 ENCODINGMETHOD = "encodingMethod"
 ENDDATE = "endDate"
 ENTITYDESCRIPTION = "entityDescription"
@@ -126,6 +127,7 @@ INSTRUMENTATION = "instrumentation"
 INTELLECTUALRIGHTS = "intellectualRights"
 INTERVAL = "interval"
 INTRODUCTION = "introduction"
+ITEMIZEDLIST = "itemizedlist"
 KEYWORD = "keyword"
 KEYWORDSET = "keywordSet"
 KEYWORDTHESAURUS = "keywordThesaurus"
@@ -134,7 +136,9 @@ LAYOUT = "layout"
 LICENSED = "licensed"
 LICENSENAME = "licenseName"
 LINENUMBER = "lineNumber"
+LISTITEM = "listitem"
 LITERALCHARACTER = "literalCharacter"
+LITERALLAYOUT = "literalLayout"
 MAINTENANCE = 'maintenance'
 MAINTENANCEUPDATEFREQUENCY = 'maintenanceUpdateFrequency'
 MARKDOWN = "markdown"
@@ -172,6 +176,7 @@ ONLINE = "online"
 ONLINEDESCRIPTION = "onlineDescription"
 ONLINEURL = "onlineUrl"
 ORDERATTRIBUTEREFERENCE = "orderAttributeReference"
+ORDEREDLIST = "orderedlist"
 ORDINAL = "ordinal"
 ORGANIZATIONNAME = "organizationName"
 OTHERENTITY = "otherEntity"
@@ -221,6 +226,8 @@ STANDARDUNIT = "standardUnit"
 STORAGETYPE = "storageType"
 STUDYAREADESCRIPTION = "studyAreaDescription"
 STUDYEXTENT = "studyExtent"
+SUBSCRIPT = "subscript"
+SUPERSCRIPT = "superscript"
 SURNAME = "surName"
 TAXONID = "taxonId"
 TAXONOMICCLASSIFICATION = "taxonomicClassification"
